package cn.com.qmth.stmms.ms.admin.exporter;

import cn.com.qmth.stmms.ms.admin.dto.*;
import cn.com.qmth.stmms.ms.commons.utils.DigitalToChineseUtil;
import cn.com.qmth.stmms.ms.commons.utils.PdfUtils;
import cn.com.qmth.stmms.ms.commons.utils.excel.ExportUtils;
import cn.com.qmth.stmms.ms.core.domain.*;
import cn.com.qmth.stmms.ms.core.repository.*;
import cn.com.qmth.stmms.ms.core.vo.Subject;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.persistence.criteria.Predicate;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * Created by yuanpan on 2017/12/23.
 */
@RestController
@RequestMapping("api/export/paper")
public class PaperExporter {

    @Autowired
    private PaperRepo paperRepo;
    @Autowired
    MarkLogRepo markLogRepo;
    @Autowired
    private MarkSubjectRepo markSubjectRepo;
    @Autowired
    private ChangeLevelRepo changeLevelRepo;
    @Autowired
    private ExamQuestionRepo examQuestionRepo;


    @Value("${sys.config.imageDir}")
    private String imagesFolder;

    @GetMapping
    public void export(@RequestParam Long workId, HttpServletResponse response) {

        List<PaperExpDTO> expPapers = new ArrayList<>();
        List<Paper> allPapers = paperRepo.findByWorkId(workId);
        for (Paper paper : allPapers) {
            String filePath = imagesFolder + "/" + paper.getWorkId() + "/" + paper.getSubject().toString() + "/" + paper.getAreaCode() + "/" + paper.getExamNumber() + ".jpg";

            File file = new File(filePath);
            if (!file.exists()) {

                expPapers.add(new PaperExpDTO(paper.getStudentName(), paper.getExamNumber(), paper.getSubject().getName()));
            }

        }

        ExportUtils.exportEXCEL("错误试卷", PaperExpDTO.class, expPapers.stream().sorted((p1, p2) -> p1.getExamNumber().compareTo(p2.getExamNumber())).collect(Collectors.toList()), response);
    }

    /**
     * 导出标准卷信息
     *
     * @param workId
     * @param subject
     * @param response
     */
    @GetMapping("{workId}/{subject}/sample")
    public void exportSample(@PathVariable Long workId, @PathVariable Subject subject, HttpServletResponse response) {
        MarkSubject markSubject = markSubjectRepo.findOne(workId + "-" + subject.name());
        //科目名称
        String subjectName = Objects.isNull(markSubject) ? subject.name() : markSubject.getName();
        List<SampleExpDTO> sampleExpDTOS = new ArrayList<>();
        List<Paper> papers = new ArrayList<>();
        if (MarkStage.ROUGH_LEVEL.equals(markSubject.getStage())) {
            papers = paperRepo.findByWorkIdAndSubjectAndIsRoughSampleTrue(workId, subject);
        } else if (MarkStage.LEVEL.equals(markSubject.getStage())) {
            papers = paperRepo.findByWorkIdAndSubjectAndIsSampleTrue(workId, subject);
        }
        if (!papers.isEmpty()) {
            for (Paper paper : papers) {
                SampleExpDTO sampleExpDTO = new SampleExpDTO();
                sampleExpDTO.setSubject(subjectName);
                sampleExpDTO.setExamNumber(paper.getExamNumber());
                if (MarkStage.ROUGH_LEVEL.equals(markSubject.getStage())) {
                    sampleExpDTO.setLevel(DigitalToChineseUtil.int2chineseNum(Integer.parseInt(paper.getRoughLevel())));
                } else if (MarkStage.LEVEL.equals(markSubject.getStage())) {
                    sampleExpDTO.setLevel(paper.getLevel());
                }
                sampleExpDTOS.add(sampleExpDTO);
            }
        }
        ExportUtils.exportEXCEL("标准卷信息", SampleExpDTO.class, sampleExpDTOS, response);
    }

    /**
     * 一键定档导出
     *
     * @param workId  工作ID
     * @param subject 科目
     */
    @GetMapping("{workId}/{subject}/oneClick")
    public void exportOneClick(@PathVariable Long workId, @PathVariable Subject subject, HttpServletResponse response) {
        MarkSubject markSubject = markSubjectRepo.findOne(workId + "-" + subject.name());
        //科目名称
        String subjectName = Objects.isNull(markSubject) ? subject.name() : markSubject.getName();
        List<OneClickExpDTO> oneClickExpDTOS = new ArrayList<>();
        List<Paper> papers = null;
        if (MarkStage.ROUGH_LEVEL.equals(markSubject.getStage())) {
            papers = paperRepo.findByWorkIdAndSubjectAndIsRoughOneClickTrue(workId, subject);
        } else if (MarkStage.LEVEL.equals(markSubject.getStage())) {
            papers = paperRepo.findByWorkIdAndSubjectAndIsOneClickTrue(workId, subject);
        }
        if (papers != null && papers.size() > 0) {
            List<Long> paperIds = papers.stream().map(Paper::getId).collect(Collectors.toList());
            List<MarkLog> markLogs = markLogRepo.findByWorkIdAndSubjectAndStageAndTestAndOperTypeAndPaperIdIn(workId, subject.name(), markSubject.getStage(), markSubject.getTest(), MarkLogOperType.ONE_CLICK_LEVEl.getId(), paperIds);
            for (int i = 0; i < markLogs.size(); i++) {
                MarkLog markLog = markLogs.get(i);
                OneClickExpDTO oneClickExpDTO = new OneClickExpDTO();
                oneClickExpDTO.setSubject(subjectName);
                oneClickExpDTO.setCreateUserName(markLog.getCreateUserName());
                oneClickExpDTO.setSeqNo(i + 1);
                Paper paper = paperRepo.findOne(markLog.getPaperId());
                oneClickExpDTO.setSecretNumber(paper == null ? "" : paper.getSecretNumber());
                if (MarkStage.ROUGH_LEVEL.equals(markSubject.getStage())) {
                    oneClickExpDTO.setOriginLevel(markLog.getOperDataBefore() == null ? "-" : markLog.getOperDataBefore().equals("-") ?
                            markLog.getOperDataBefore() : DigitalToChineseUtil.int2chineseNum(Integer.parseInt(markLog.getOperDataBefore())))
                    ;
                    oneClickExpDTO.setLevel(DigitalToChineseUtil.int2chineseNum(Integer.parseInt(markLog.getOperDataAfter())));
                } else if (MarkStage.LEVEL.equals(markSubject.getStage())) {
                    oneClickExpDTO.setOriginLevel(markLog.getOperDataBefore() == null ? "-" : markLog.getOperDataBefore());
                    oneClickExpDTO.setLevel(markLog.getOperDataAfter());
                }
                oneClickExpDTOS.add(oneClickExpDTO);
            }
        }
        ExportUtils.exportEXCEL("专家复评导出", OneClickExpDTO.class, oneClickExpDTOS, response);
    }

    /**
     * 改档信息导出
     *
     * @param workId   工作ID
     * @param subject  科目
     * @param response response对象
     */
    @GetMapping("{workId}/{subject}/changeLevel")
    public void exportChangeLevel(@PathVariable Long workId, @PathVariable Subject subject, HttpServletResponse response) throws Exception {
        MarkSubject markSubject = markSubjectRepo.findOne(workId + "-" + subject.name());
        //科目名称
        String subjectName = Objects.isNull(markSubject) ? subject.name() : markSubject.getName();
        List<ChangeLevel> changeLevels = changeLevelRepo.findByWorkIdAndSubjectAndAuditStatusAndStage(workId, subject.name(), markSubject.getStage());

        List<JSONObject> datas = new ArrayList<>();
        for (ChangeLevel changeLevel : changeLevels) {
            JSONObject object = new JSONObject();
            Paper paper = paperRepo.findOne(changeLevel.getPaperId());
            object.put("secretNumber", paper.getSecretNumber());
            // 细分档改的是粗分档大档位
            if (MarkStage.LEVEL.equals(markSubject.getStage())) {
                object.put("oldLevel", DigitalToChineseUtil.int2chineseNum(Integer.parseInt(changeLevel.getOriginalLevel())));
                object.put("newLevel", DigitalToChineseUtil.int2chineseNum(Integer.parseInt(changeLevel.getSuggestLevel())));
            } else {
                object.put("oldLevel", changeLevel.getOriginalLevel());
                object.put("newLevel", changeLevel.getSuggestLevel());
            }
            datas.add(object);
        }
        PdfUtils.exportPdf(subjectName + "科目改档签字表", datas, response);
    }

    /**
     * 导出标记试卷信息
     *
     * @param workId   工作ID
     * @param response response对象
     */
    @GetMapping("{workId}/mark")
    public void exportMark(@PathVariable Long workId, HttpServletResponse response) {
        List<MarkExpDTO> markExpDTOS = new ArrayList<>();
        List<Paper> papers = paperRepo.findByWorkIdAndIsAdminMarkTrue(workId);
        for (Paper paper : papers) {
            MarkExpDTO markExpDTO = new MarkExpDTO();
            markExpDTO.setWorkId(workId);
            Subject subject = paper.getSubject();
            markExpDTO.setSubjectId(String.valueOf(subject.ordinal() + 1));
            markExpDTO.setSubject(subject.name());
            String subjectName = subject.getName();
            markExpDTO.setSubjectName(subjectName);
            markExpDTO.setExamNumber(paper.getExamNumber());
            markExpDTO.setStudentName(paper.getStudentName());
            markExpDTOS.add(markExpDTO);
        }
        ExportUtils.exportEXCEL("标记试卷信息", MarkExpDTO.class, markExpDTOS, response);
    }

    /**
     * 试卷管理-导出
     */
    @GetMapping(value = "export")
    public void export(@RequestParam Long workId,
                       @RequestParam(required = false) String areaCode,
                       @RequestParam Subject subject,
                       @RequestParam(required = false) String startNumber,
                       @RequestParam(required = false) String endNumber,
                       @RequestParam(required = false) Boolean isManual,
                       @RequestParam(required = false) Boolean missing,
                       @RequestParam(required = false) Boolean isRelate,
                       @RequestParam(required = false) String studentName,
                       @RequestParam(required = false) Long scanUserId,
                       @RequestParam(required = false) Boolean isMark,
                       @RequestParam(required = false) Boolean sizeAbnormal, // 大小异常
                       @RequestParam(required = false) String sortBy,
                       HttpServletResponse response) {
        Sort sort = null;
        if (Objects.equals("1", sortBy)) {
            sort = new Sort(Sort.Direction.DESC, "uploadedOn");
        }
        if (Objects.equals("2", sortBy)) {
            sort = new Sort(Sort.Direction.ASC, "examNumber");
        }
        Specification<Paper> specification = (root, query, builder) -> {
            List<Predicate> predicates = new ArrayList<>();
            predicates.add(builder.equal(root.get("workId"), workId));
            if (scanUserId != null) {
                predicates.add(builder.equal(root.get("scanUserId"), scanUserId));
            }
            if (areaCode != null && !"".equals(areaCode)) {
                predicates.add(builder.equal(root.get("areaCode"), areaCode));
            }
            if (subject != null) {
                predicates.add(builder.equal(root.get("subject"), subject));
            }
            if (!StringUtils.isEmpty(startNumber) && !StringUtils.isEmpty(endNumber)) {
                predicates.add(builder.between(root.get("examNumber"), startNumber, endNumber));
            } else if (!StringUtils.isEmpty(startNumber) && StringUtils.isEmpty(endNumber)) {
                predicates.add(builder.equal(root.get("examNumber"), startNumber));
            } else if (StringUtils.isEmpty(startNumber) && !StringUtils.isEmpty(endNumber)) {
                predicates.add(builder.equal(root.get("examNumber"), endNumber));
            }
            if (isManual != null) {
                predicates.add(builder.equal(root.get("isManual"), isManual));
            }
            if (missing != null) {
                predicates.add(builder.equal(root.get("isMissing"), missing));
            }
            if (isRelate != null) {
                predicates.add(builder.equal(root.get("isRelate"), isRelate));
            }
            if (isMark != null) {
                predicates.add(builder.equal(root.get("isAdminMark"), isMark));
            }
            if (sizeAbnormal != null) {
                predicates.add(builder.equal(root.get("sizeAbnormal"), sizeAbnormal));
            }
            //考生姓名
            if (studentName != null && !"".equals(studentName)) {
                predicates.add(builder.equal(root.get("studentName"), studentName));
            }
            return builder.and(predicates.toArray(new Predicate[predicates.size()]));
        };
        List<Paper> paperList = paperRepo.findAll(specification, sort);

        ExamQuestion examQuestion = examQuestionRepo.findByWorkIdAndSubjectAndAreaCode(workId, subject, areaCode);

        List<PaperStudentExpDTO> paperStudentExpDTOS = new ArrayList<>();
        for (Paper paper : paperList) {
            PaperStudentExpDTO paperStudentExpDTO = new PaperStudentExpDTO();
            paperStudentExpDTO.setSubject(paper.getSubject().name());
            paperStudentExpDTO.setSubjectName(paper.getSubject().getName());
            paperStudentExpDTO.setAreaName(examQuestion != null ? examQuestion.getAreaName() : "");
            paperStudentExpDTO.setExamNumber(paper.getExamNumber());
            paperStudentExpDTO.setStudentName(paper.getStudentName());
            paperStudentExpDTOS.add(paperStudentExpDTO);
        }
        ExportUtils.exportEXCEL("试卷管理-考生信息", PaperStudentExpDTO.class, paperStudentExpDTOS, response);
    }
}
