package cn.com.qmth.stmms.ms.core.domain;

import cn.com.qmth.stmms.ms.core.domain.task.MarkTaskLevel;
import cn.com.qmth.stmms.ms.core.domain.task.MarkTaskScore;

import javax.persistence.*;
import javax.validation.constraints.NotNull;
import java.util.Date;

@Entity
@Table(name = "change_level_task")
public class ChangeLevelTask {

    @Id
    @GeneratedValue
    private Long id;

    private Long workId;
    private Long questionId;
    @NotNull
    @ManyToOne
    @JoinColumn(name = "paperId")
    private Paper paper;
    private String subject;
    @NotNull
    @Enumerated(value = EnumType.ORDINAL)
    private MarkStage stage;
    @NotNull
    private Long markerId;
    @NotNull
    private String markerName;
    private String secretNumber;
    private String result;
    private Boolean confirmChangeStage;
    @Temporal(value = TemporalType.TIMESTAMP)
    private Date confirmOn;
    @Temporal(value = TemporalType.TIMESTAMP)
    private Date createdOn;

    public static ChangeLevelTask toChangeLevelTask(MarkTaskLevel m, String suggestLevel) {
        ChangeLevelTask changeLevelTask = new ChangeLevelTask();
        changeLevelTask.setWorkId(m.getWorkId());
        changeLevelTask.setQuestionId(m.getQuestionId());
        changeLevelTask.setPaper(m.getPaper());
        changeLevelTask.setSubject(m.getSubject().name());
        changeLevelTask.setStage(m.getStage());
        changeLevelTask.setMarkerId(m.getMarkerId());
        changeLevelTask.setMarkerName(m.getMarkerName());
        changeLevelTask.setResult(suggestLevel);
        changeLevelTask.setConfirmChangeStage(false);
        changeLevelTask.setCreatedOn(new Date());
        return changeLevelTask;
    }

    public static ChangeLevelTask toChangeLevelTask(MarkTaskScore m, String suggestLevel, Long random) {
        ChangeLevelTask changeLevelTask = new ChangeLevelTask();
        changeLevelTask.setWorkId(m.getWorkId());
        changeLevelTask.setQuestionId(m.getQuestionId());
        changeLevelTask.setPaper(m.getPaper());
        changeLevelTask.setSubject(m.getSubject().name());
        changeLevelTask.setStage(m.getStage());
        changeLevelTask.setMarkerId(m.getMarkerId());
        changeLevelTask.setMarkerName(m.getMarkerName());
        // 默认加上前缀4
        changeLevelTask.setSecretNumber(4 + String.valueOf(random));
        changeLevelTask.setResult(suggestLevel);
        changeLevelTask.setConfirmChangeStage(false);
        changeLevelTask.setCreatedOn(new Date());
        return changeLevelTask;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getWorkId() {
        return workId;
    }

    public void setWorkId(Long workId) {
        this.workId = workId;
    }

    public Long getQuestionId() {
        return questionId;
    }

    public void setQuestionId(Long questionId) {
        this.questionId = questionId;
    }

    public Paper getPaper() {
        return paper;
    }

    public void setPaper(Paper paper) {
        this.paper = paper;
    }

    public String getSubject() {
        return subject;
    }

    public void setSubject(String subject) {
        this.subject = subject;
    }

    public MarkStage getStage() {
        return stage;
    }

    public void setStage(MarkStage stage) {
        this.stage = stage;
    }

    public Long getMarkerId() {
        return markerId;
    }

    public void setMarkerId(Long markerId) {
        this.markerId = markerId;
    }

    public String getMarkerName() {
        return markerName;
    }

    public void setMarkerName(String markerName) {
        this.markerName = markerName;
    }

    public String getSecretNumber() {
        return secretNumber;
    }

    public void setSecretNumber(String secretNumber) {
        this.secretNumber = secretNumber;
    }

    public String getResult() {
        return result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public Boolean getConfirmChangeStage() {
        return confirmChangeStage;
    }

    public void setConfirmChangeStage(Boolean confirmChangeStage) {
        this.confirmChangeStage = confirmChangeStage;
    }

    public Date getConfirmOn() {
        return confirmOn;
    }

    public void setConfirmOn(Date confirmOn) {
        this.confirmOn = confirmOn;
    }

    public Date getCreatedOn() {
        return createdOn;
    }

    public void setCreatedOn(Date createdOn) {
        this.createdOn = createdOn;
    }
}
