package cn.com.qmth.stmms.ms.marking.assembler;

import cn.com.qmth.stmms.ms.commons.config.ImageConfig;
import cn.com.qmth.stmms.ms.commons.config.SystemConfig;
import cn.com.qmth.stmms.ms.commons.constant.SystemConstant;
import cn.com.qmth.stmms.ms.commons.utils.MD5Util;
import cn.com.qmth.stmms.ms.core.cache.ParamCache;
import cn.com.qmth.stmms.ms.core.domain.*;
import cn.com.qmth.stmms.ms.core.domain.task.MarkTaskLevel;
import cn.com.qmth.stmms.ms.core.domain.task.MarkTaskRoughLevel;
import cn.com.qmth.stmms.ms.core.domain.user.MarkUser;
import cn.com.qmth.stmms.ms.core.repository.ChangeLevelRepo;
import cn.com.qmth.stmms.ms.core.repository.MarkLogRepo;
import cn.com.qmth.stmms.ms.core.repository.MarkUserRepo;
import cn.com.qmth.stmms.ms.core.repository.StudentRepo;
import cn.com.qmth.stmms.ms.marking.dto.MarkTaskDTO;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * Created by zhengmin on 2016/10/12.
 */
@Component
public class MarkTaskRoughLevelAssembler {

    @Resource
    private SystemConfig systemConfig;

    @Resource
    ImageConfig imageConfig;

    @Resource
    StudentRepo studentRepo;

    @Resource
    MarkLogRepo markLogRepo;

    @Resource
    MarkUserRepo markUserRepo;

    @Resource
    ChangeLevelRepo changeLevelRepo;

    public MarkTaskDTO toDTO(MarkTaskRoughLevel markTask) {

        MarkTaskDTO markTaskDTO = null;
        if (markTask != null) {
            markTaskDTO = new MarkTaskDTO();
            markTaskDTO.setId(markTask.getId());
            markTaskDTO.setRejected(markTask.isRejected());
            markTaskDTO.setMarkerId(markTask.getMarkerId());
            MarkUser markUser = markUserRepo.findOne(markTask.getMarkerId());
            markTaskDTO.setLoginName(markUser.getLoginName());
            markTaskDTO.setMarker(markTask.getMarkerName());
            markTaskDTO.setUpdatedOn(markTask.getUpdatedOn());
            markTaskDTO.setResult(markTask.getResult());
            Paper paper = markTask.getPaper();
            markTaskDTO.setLevel(markTask.getResult());
            markTaskDTO.setOriginLevel(markTask.getOriginLevel() == null ? "" : markTask.getOriginLevel());
            markTaskDTO.setSn(markTask.getSecretNumber());
            markTaskDTO.setRedoLevel(paper.getRedoLevel());
            String imgSrc = null;
            String thumbSrc = null;
            String fileName = paper.getExamNumber();
            Student student = studentRepo.findByWorkIdAndExamNumber(paper.getWorkId(), paper.getExamNumber());
            //0：随机码 1：考号
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getNameRule() == 1) {
                fileName = MD5Util.getImageRuleMd5(paper.getWorkId(), paper.getSubject().ordinal(), student.getAreaCode(), student.getExamNumber(), student.getId());
            }
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getImageEncrypt() == 1) {
                imgSrc = systemConfig.getImageUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.IMAGE);
                thumbSrc = systemConfig.getThumbUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.THUMB);
            } else {
                imgSrc = systemConfig.getImageUrl(markTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
                thumbSrc = systemConfig.getThumbUrl(markTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
            }
            markTaskDTO.setThumbSrc(thumbSrc);
            markTaskDTO.setImgSrc(imgSrc);
            markTaskDTO.setRoughSample(paper.isRoughSample());
            markTaskDTO.setSample(paper.isSample());
            markTaskDTO.setMarkByLeader(paper.isMarkByLeader());
            markTaskDTO.setRandomSeqNew(markTask.getRandomSeqNew());
            markTaskDTO.setRandomSeq(markTask.getRandomSeq());
            markTaskDTO.setPaperId(paper.getId());
            markTaskDTO.setSerialNumber(markTask.getSerialNumber());
            if (Objects.nonNull(markTask.getDisplayNumber())) {
                markTaskDTO.setDisplayNumber(markTask.getDisplayNumber() == 1);
            }
            markTaskDTO.setShift(paper.isShift());
            markTaskDTO.setShiftScore(paper.isShiftScore());

            markTaskDTO.setIsRejectedByLeader(paper.isRejectedByLeader() != null && paper.isRejectedByLeader());
            //打回总次数
            int rejectedCount = markLogRepo.countByWorkIdAndPaperIdAndOperType(paper.getWorkId(), paper.getId(), Objects.nonNull(paper.isRejectedByLeader()) && paper.isRejectedByLeader() ? MarkLogOperType.CALLBACK_LEVEl.getId() : MarkLogOperType.SYSTEM_CALLBACK_LEVEl.getId());
            markTaskDTO.setRejectedCount(rejectedCount);
            markTaskDTO.setDeviationDirection(markTask.getDeviationDirection());
            markTaskDTO.setMark(markTask.isMark());
        }
        return markTaskDTO;
    }

    public MarkTaskDTO toDTO(MarkTaskRoughLevel markTask, boolean oldRejected, boolean oldShift, boolean oldShiftScore) {
        MarkTaskDTO markTaskDTO = null;
        if (markTask != null) {
            markTaskDTO = new MarkTaskDTO();
            markTaskDTO.setId(markTask.getId());
            markTaskDTO.setWorkId(markTask.getWorkId());
            markTaskDTO.setSubject(markTask.getSubject());
            markTaskDTO.setRejected(markTask.isRejected());
            markTaskDTO.setOldRejected(oldRejected);
            markTaskDTO.setMarkerId(markTask.getMarkerId());
            markTaskDTO.setMarker(markTask.getMarkerName());
            markTaskDTO.setUpdatedOn(markTask.getUpdatedOn());
            markTaskDTO.setResult(markTask.getResult());
            Paper paper = markTask.getPaper();
            markTaskDTO.setLevel(markTask.getResult());
            markTaskDTO.setOriginLevel(markTask.getOriginLevel());
            markTaskDTO.setSn(markTask.getSecretNumber());
            markTaskDTO.setRedoLevel(paper.getRedoLevel());
            String imgSrc = null;
            String thumbSrc = null;
            String fileName = paper.getExamNumber();
            Student student = studentRepo.findByWorkIdAndExamNumber(paper.getWorkId(), paper.getExamNumber());
            //0：随机码 1：考号
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getNameRule() == 1) {
                fileName = MD5Util.getImageRuleMd5(paper.getWorkId(), paper.getSubject().ordinal(), student.getAreaCode(), student.getExamNumber(), student.getId());
            }
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getImageEncrypt() == 1) {
                imgSrc = systemConfig.getImageUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.IMAGE);
                thumbSrc = systemConfig.getThumbUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.THUMB);
            } else {
                imgSrc = systemConfig.getImageUrl(markTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
                thumbSrc = systemConfig.getThumbUrl(markTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
            }
            markTaskDTO.setThumbSrc(thumbSrc);
            markTaskDTO.setImgSrc(imgSrc);
            markTaskDTO.setSample(paper.isSample());
            markTaskDTO.setMarkByLeader(paper.isMarkByLeader());
            markTaskDTO.setRandomSeqNew(markTask.getRandomSeqNew());
            markTaskDTO.setRandomSeq(markTask.getRandomSeq());
            markTaskDTO.setPaperId(paper.getId());
            markTaskDTO.setShift(oldShift);
            markTaskDTO.setShiftScore(oldShiftScore);
            markTaskDTO.setDateMineResult(markTask.getDateMineResult());
        }
        return markTaskDTO;
    }

    /**
     * 改档，改档打分
     */
    public MarkTaskDTO toShiftDTO(ChangeLevelTask changeLevelTask) {

        MarkTaskDTO markTaskDTO = null;
        if (changeLevelTask != null) {
            markTaskDTO = new MarkTaskDTO();
            markTaskDTO.setId(changeLevelTask.getId());
            markTaskDTO.setMarkerId(changeLevelTask.getMarkerId());
            markTaskDTO.setMarker(changeLevelTask.getMarkerName());
            markTaskDTO.setUpdatedOn(changeLevelTask.getCreatedOn());
//            markTaskDTO.setResult(markTask.getResult());
            Paper paper = changeLevelTask.getPaper();
            if (paper.isShift()) {
                ChangeLevel changeLevel = changeLevelRepo.findByWorkIdAndSubjectAndPaperIdAndAuditStatusAndStageAndIsCurr(changeLevelTask.getWorkId(), changeLevelTask.getSubject(), MarkStage.LEVEL, paper.getId());
                markTaskDTO.setLevel(changeLevel.getSuggestLevel());
                markTaskDTO.setOriginLevel(changeLevel != null ? changeLevel.getOriginalLevel() : "");
                markTaskDTO.setRedoLevel(changeLevel.getSuggestLevel());
            }
            if (paper.isShiftScore()) {
                markTaskDTO.setLevel(paper.getLevel());
            }
//            markTaskDTO.setSn(markTask.getSecretNumber());

            String imgSrc = null;
            String thumbSrc = null;
            String fileName = paper.getExamNumber();
            Student student = studentRepo.findByWorkIdAndExamNumber(paper.getWorkId(), paper.getExamNumber());
            //0：随机码 1：考号
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getNameRule() == 1) {
                fileName = MD5Util.getImageRuleMd5(paper.getWorkId(), paper.getSubject().ordinal(), student.getAreaCode(), student.getExamNumber(), student.getId());
            }
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getImageEncrypt() == 1) {
                imgSrc = systemConfig.getImageUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.IMAGE);
                thumbSrc = systemConfig.getThumbUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.THUMB);
            } else {
                imgSrc = systemConfig.getImageUrl(changeLevelTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
                thumbSrc = systemConfig.getThumbUrl(changeLevelTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
            }
            markTaskDTO.setThumbSrc(thumbSrc);
            markTaskDTO.setImgSrc(imgSrc);
            markTaskDTO.setSample(paper.isSample());
            markTaskDTO.setMarkByLeader(paper.isMarkByLeader());
//            markTaskDTO.setRandomSeqNew(markTask.getRandomSeqNew());
//            markTaskDTO.setRandomSeq(markTask.getRandomSeq());
            markTaskDTO.setPaperId(paper.getId());
//            markTaskDTO.setSerialNumber(markTask.getSerialNumber());
//            if (Objects.nonNull(markTask.getDisplayNumber())) {
//                markTaskDTO.setDisplayNumber(markTask.getDisplayNumber() == 1);
//            }
            markTaskDTO.setShift(!changeLevelTask.getConfirmChangeStage() && paper.isShift());
            markTaskDTO.setShiftScore(paper.isShiftScore());
//            markTaskDTO.setMark(markTask.isMark());
        }
        return markTaskDTO;
    }

    public MarkTaskDTO toSelfCheckDTO(MarkTaskRoughLevel markTask) {
        MarkTaskDTO markTaskDTO = null;
        if (markTask != null) {
            markTaskDTO = new MarkTaskDTO();
            markTaskDTO.setMarkerId(markTask.getMarkerId());
            MarkUser markUser = markUserRepo.findOne(markTask.getMarkerId());
            markTaskDTO.setLoginName(markUser.getLoginName());
            markTaskDTO.setMarker(markTask.getMarkerName());
            markTaskDTO.setUpdatedOn(markTask.getUpdatedOn());
            Paper paper = markTask.getPaper();
            markTaskDTO.setSn(markTask.getSecretNumber());
            String imgSrc = null;
            String thumbSrc = null;
            String fileName = paper.getExamNumber();
            Student student = studentRepo.findByWorkIdAndExamNumber(paper.getWorkId(), paper.getExamNumber());
            //0：随机码 1：考号
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getNameRule() == 1) {
                fileName = MD5Util.getImageRuleMd5(paper.getWorkId(), paper.getSubject().ordinal(), student.getAreaCode(), student.getExamNumber(), student.getId());
            }
            if (ParamCache.collectConfigMap.get(String.valueOf(paper.getWorkId())).getImageEncrypt() == 1) {
                imgSrc = systemConfig.getImageUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.IMAGE);
                thumbSrc = systemConfig.getThumbUrl(paper.getWorkId(), paper.getSubject().ordinal(), student.getId(), SystemConstant.THUMB);
            } else {
                imgSrc = systemConfig.getImageUrl(markTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
                thumbSrc = systemConfig.getThumbUrl(markTask.getWorkId(), paper.getSubject().toString(), paper.getAreaCode(), fileName);
            }
            markTaskDTO.setThumbSrc(thumbSrc);
            markTaskDTO.setImgSrc(imgSrc);
            markTaskDTO.setRandomSeqNew(markTask.getRandomSeqNew());
            markTaskDTO.setRandomSeq(markTask.getRandomSeq());
            markTaskDTO.setPaperId(paper.getId());
            markTaskDTO.setSerialNumber(markTask.getSerialNumber());
            if (Objects.nonNull(markTask.getDisplayNumber())) {
                markTaskDTO.setDisplayNumber(markTask.getDisplayNumber() == 1);
            }
            markTaskDTO.setSelfCheck(true);
        }
        return markTaskDTO;
    }
}