package cn.com.qmth.stmms.ms.marking.service;

import cn.com.qmth.stmms.ms.commons.lock.LockService;
import cn.com.qmth.stmms.ms.commons.lock.LockType;
import cn.com.qmth.stmms.ms.core.domain.ChangeLevelTask;
import cn.com.qmth.stmms.ms.core.domain.MarkStage;
import cn.com.qmth.stmms.ms.core.repository.ChangeLevelTaskRepo;
import cn.com.qmth.stmms.ms.core.repository.PaperRepo;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Service
public class ChangeLevelTaskService {

    @Resource
    private ChangeLevelTaskRepo changeLevelTaskRepo;
    @Resource
    private PaperRepo paperRepo;
    @Resource
    private LockService lockService;


    @Transactional
    public Map confirmTask(Long changeLevelTaskId) {
        ChangeLevelTask changeLevelTask = changeLevelTaskRepo.findOne(changeLevelTaskId);
        if (changeLevelTask == null) {
            throw new RuntimeException("改档确认任务不存在");
        }
        Boolean status;
        try {
            lockService.waitlock(LockType.PAPER, changeLevelTask.getPaper().getId());
            status = this.confirm(changeLevelTask);
        } catch (Exception e) {
            throw new RuntimeException("改档确认任务异常");
        } finally {
            lockService.unlock(LockType.PAPER, changeLevelTask.getPaper().getId());
        }
        Map map = new HashMap<>();
        map.put("status", status);
        map.put("hasSelfTask", false);
        return map;
    }

    @Transactional
    public boolean confirm(ChangeLevelTask changeLevelTask) {
        changeLevelTask.setConfirmChangeStage(true);
        changeLevelTask.setConfirmOn(new Date());
        changeLevelTaskRepo.saveAndFlush(changeLevelTask);

        // 确认改档，只修改试卷最终档位，不改变评卷员已评档位值
        if (MarkStage.LEVEL.equals(changeLevelTask.getStage())) {
            if (changeLevelTaskRepo.countByPaperIdAndSubjectAndStageAndConfirmChangeStage(changeLevelTask.getPaper().getId(), changeLevelTask.getSubject(), changeLevelTask.getStage(), false) == 0) {
                paperRepo.updateRoughLevelById(changeLevelTask.getPaper().getId(), changeLevelTask.getResult());
            }
        } else if (MarkStage.SCORE.equals(changeLevelTask.getStage())) {
            if (changeLevelTaskRepo.countByPaperIdAndSubjectAndStageAndConfirmChangeStage(changeLevelTask.getPaper().getId(), changeLevelTask.getSubject(), changeLevelTask.getStage(), false) == 0) {
                paperRepo.updateLevelByIdAndShift(changeLevelTask.getPaper().getId(), changeLevelTask.getResult());
            }
        }
        return true;
    }
}
